@@ -1,9 +1,16 @@
+##
+# name:      WikiText
+# abstract:  Wiki Text Conversion Tools
+# author:    Ingy döt Net <ingy@cpan.org>
+# license:   perl
+# copyright: 2008, 2011
+
 package WikiText;
+use 5.008003;
 use strict;
 use warnings;
 
-use 5.006001;
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 sub new {
     my $class = shift;
@@ -27,12 +34,6 @@ sub to_html {
 
 1;
 
-=encoding utf8
-
-=head1 NAME
-
-WikiText - Wiki Text Conversion Tools
-
 =head1 SYNOPSIS
 
     use WikiText::Sample::Parser;
@@ -58,18 +59,3 @@ form can be HTML, an AST or another wiki markup.
 Some formats are richer than others. The module WikiText::WikiByte defines a
 bytecode format. The bytecode format is rich enough to be a receiver for any
 parse, therefore it makes an ideal intermediate format.
-
-=head1 AUTHOR
-
-Ingy döt Net <ingy@cpan.org>
-
-=head1 COPYRIGHT
-
-Copyright (c) 2008. Ingy döt Net.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-See http://www.perl.com/perl/misc/Artistic.html
-
-=cut
